==> phpgroupware-0.9.16.011.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/ca.php <==
<?php
//
// phpSysInfo -A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// $Id: ca.php,v 1.1.2.1 2003/11/01 22:10:21 skwashd Exp $

// Traductor: Miquel Guillamet Montalat
// E-mail: mikelet15@netscape.com Web: http://gitx.dhs.org

$text['title']       = 'Informaci del Sistema';

$text['vitals']      = 'Vital';
$text['hostname']    = 'Nom del Sistema';
$text['ip']          = 'Direcci IP';
$text['kversion']    = 'Versi del Kernel';
$text['uptime']      = 'Uptime';
$text['users']       = 'Usuaris actuals';
$text['loadavg']     = 'Carrega del Servidor';

$text['hardware']    = 'Informaci del Hardware';
$text['numcpu']      = 'Processadors';
$text['cpumodel']    = 'Model';
$text['mhz']         = 'Frequncia en MHz';
$text['cache']       = 'RAM';
$text['bogomips']    = 'Bogomips';
$text['pci']         = 'Dispositius PCI';
$text['ide']         = 'Dispositius IDE';
$text['scsi']        = 'Dispositius SCSI';

$text['netusage']    = 'Utilitzaci de la XARXA';
$text['device']      = 'Dispositiu';
$text['received']    = 'Rebut';
$text['sent']        = 'Enviat';
$text['errors']      = 'Errors/Perduts';

$text['memusage']    = 'Utilitzaci de la RAM';
$text['phymem']      = 'Memoria Fisica';
$text['swap']        = 'Swap';

$text['fs']          = 'Particions Montades';
$text['mount']       = 'Montat a';
$text['partition']   = 'Partici';

$text['percent']     = 'Capacitat';
$text['type']        = 'Tipus';
$text['free']        = 'Lliure';
$text['used']        = 'Usat';
$text['size']        = 'Tamany';
$text['totals']      = 'Totals';

$text['kb']          = 'KB';
$text['mg']          = 'MB';
$text['gb']          = 'GB';

$text['none']        = 'ningun';

$text['capacity']    = 'Capacitat';

$text['template']    = 'Themes';
$text['language']    = 'Llenguatge';
$text['submit']      = 'Enviar';
$text['created']     = 'Creat per';

$text['days']        = 'dies';
$text['hours']       = 'hores';
$text['minutes']     = 'minuts';
?>

==> phpgroupware-0.9.16.017.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/ca.php <==
<?php
//
// phpSysInfo -A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// $Id: ca.php 21052 2010-03-25 22:44:08Z Caeies $
//
// Traductor: Miquel Guillamet Montalat
// E-mail: mikelet15@netscape.com Web: http://gitx.dhs.org
//
$text['title']       = 'Informaci del Sistema';

$text['vitals']      = 'Vital';
$text['hostname']    = 'Nom del Sistema';
$text['ip']          = 'Direcci IP';
$text['kversion']    = 'Versi del Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']      = 'Uptime';
$text['users']       = 'Usuaris actuals';
$text['loadavg']     = 'Carrega del Servidor';

$text['hardware']    = 'Informaci del Hardware';
$text['numcpu']      = 'Processadors';
$text['cpumodel']    = 'Model';
$text['cpuspeed']    = 'Frequncia en MHz';
$text['busspeed']    = 'BUS Speed';
$text['cache']       = 'RAM';
$text['bogomips']    = 'Bogomips';

$text['pci']         = 'Dispositius PCI';
$text['ide']         = 'Dispositius IDE';
$text['scsi']        = 'Dispositius SCSI';
$text['usb']         = 'Dispisitius USB';

$text['netusage']    = 'Utilitzaci de la XARXA';
$text['device']      = 'Dispositiu';
$text['received']    = 'Rebut';
$text['sent']        = 'Enviat';
$text['errors']      = 'Errors/Perduts';

$text['memusage']    = 'Utilitzaci de la RAM';
$text['phymem']      = 'Memoria Fisica';
$text['swap']        = 'Swap';

$text['fs']          = 'Particions Montades';
$text['mount']       = 'Montat a';
$text['partition']   = 'Partici';

$text['percent']     = 'Capacitat';
$text['type']        = 'Tipus';
$text['free']        = 'Lliure';
$text['used']        = 'Usat';
$text['size']        = 'Tamany';
$text['totals']      = 'Totals';

$text['kb']          = 'KB';
$text['mb']          = 'MB';
$text['gb']          = 'GB';

$text['none']        = 'ningun';

$text['capacity']    = 'Capacitat';

$text['template']    = 'Themes';
$text['language']    = 'Llenguatge';
$text['submit']      = 'Enviar';
$text['created']     = 'Creat per';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']        = 'dies';
$text['hours']       = 'hores';
$text['minutes']     = 'minuts';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&deg;C';
$text['degreeF']        = '&deg;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']	= 'Established Network Connections';
?>
